==> blancoNLpackGenerator-0.0.95-src.zip: src/blanco/nlpack/generator/task/BlancoNLpackGeneratorConvertXliff2PropertiesTask.java <==
/*
 * ̃\[XR[h blanco FrameworkɂĎĂ܂B
 * Apache Ant^XN [BlancoNLpackGeneratorConvertXliff2Properties]̃NX
 */
package blanco.nlpack.generator.task;

import org.apache.tools.ant.BuildException;
import org.apache.tools.ant.Task;

import blanco.nlpack.generator.task.valueobject.BlancoNLpackGeneratorConvertXliff2PropertiesProcessInput;

/**
 * Apache Ant^XN [BlancoNLpackGeneratorConvertXliff2Properties]̃NXB
 *
 * [XLIFFΉc[] JavaAvP[V(EclipsevOC)  XLIFFt@C(*.xlf) 猾pbN쐬܂B<br>
 * ̃NXł́AApache Ant^XNňʓIɕKvȃ`FbNȂǂ̃R[fBO肵܂B
 * ۂ̏ pbP[W[blanco.nlpack.generator.task]BlancoNLpackGeneratorConvertXliff2PropertiesBatchProcessNX쐬ċLqĂB<br>
 * <br>
 * Ant^XNւ̑gݍݗ<br>
 * <pre>
 * &lt;taskdef name=&quot;blanconlpackgeneratorconvertxliff2properties&quot; classname=&quot;blanco.nlpack.generator.task.BlancoNLpackGeneratorConvertXliff2PropertiesTask">
 *     &lt;classpath&gt;
 *         &lt;fileset dir=&quot;lib&quot; includes=&quot;*.jar&quot; /&gt;
 *         &lt;fileset dir=&quot;lib.ant&quot; includes=&quot;*.jar&quot; /&gt;
 *     &lt;/classpath&gt;
 * &lt;/taskdef&gt;
 * </pre>
 */
public class BlancoNLpackGeneratorConvertXliff2PropertiesTask extends Task {
    /**
     * [XLIFFΉc[] JavaAvP[V(EclipsevOC)  XLIFFt@C(*.xlf) 猾pbN쐬܂B
     */
    protected BlancoNLpackGeneratorConvertXliff2PropertiesProcessInput fInput = new BlancoNLpackGeneratorConvertXliff2PropertiesProcessInput();

    /**
     * [XLIFFΉc[] JavaAvP[V(EclipsevOC)  XLIFFt@C(*.xlf) 猾pbN쐬܂B
     */
    protected boolean fIsFieldSourcedirProcessed = false;

    /**
     * [XLIFFΉc[] JavaAvP[V(EclipsevOC)  XLIFFt@C(*.xlf) 猾pbN쐬܂B
     */
    protected boolean fIsFieldTargetdirProcessed = false;

    /**
     * [XLIFFΉc[] JavaAvP[V(EclipsevOC)  XLIFFt@C(*.xlf) 猾pbN쐬܂B
     */
    protected boolean fIsFieldXliffdirProcessed = false;

    /**
     * [XLIFFΉc[] JavaAvP[V(EclipsevOC)  XLIFFt@C(*.xlf) 猾pbN쐬܂B
     */
    protected boolean fIsFieldTmpdirProcessed = false;

    /**
     * verbose[hœ삳邩ǂB
     *
     * @param arg verbose[hœ삳邩ǂB
     */
    public void setVerbose(final boolean arg) {
        fInput.setVerbose(arg);
    }

    /**
     * verbose[hœ삳邩ǂB
     *
     * @return verbose[hœ삳邩ǂB
     */
    public boolean getVerbose() {
        return fInput.getVerbose();
    }

    /**
     * Ant^XN[sourcedir]Agr[g̃Zb^[\bhB
     *
     * ڔԍ: 1<br>
     * \[XfBNgB*.jart@CWJEclipsevOCB<br>
     *
     * @param arg Zbgl
     */
    public void setSourcedir(final String arg) {
        fInput.setSourcedir(arg);
        fIsFieldSourcedirProcessed = true;
    }

    /**
     * Ant^XN[sourcedir]Agr[g̃Qb^[\bhB
     *
     * ڔԍ: 1<br>
     * \[XfBNgB*.jart@CWJEclipsevOCB<br>
     * K{Agr[głBApache Ant^XNŕKlw肳܂B<br>
     *
     * @return ̃tB[h̒l
     */
    public String getSourcedir() {
        return fInput.getSourcedir();
    }

    /**
     * Ant^XN[targetdir]Agr[g̃Zb^[\bhB
     *
     * ڔԍ: 2<br>
     * pbNi[o͐fBNgB<br>
     *
     * @param arg Zbgl
     */
    public void setTargetdir(final String arg) {
        fInput.setTargetdir(arg);
        fIsFieldTargetdirProcessed = true;
    }

    /**
     * Ant^XN[targetdir]Agr[g̃Qb^[\bhB
     *
     * ڔԍ: 2<br>
     * pbNi[o͐fBNgB<br>
     * K{Agr[głBApache Ant^XNŕKlw肳܂B<br>
     *
     * @return ̃tB[h̒l
     */
    public String getTargetdir() {
        return fInput.getTargetdir();
    }

    /**
     * Ant^XN[xliffdir]Agr[g̃Zb^[\bhB
     *
     * ڔԍ: 3<br>
     * XLIFFt@Ci[Ă͐惋[gEtH_w肵܂BXLIFFt@C Bundle-SymbolicName fBNgɊi[邱ƂOƂ܂B<br>
     *
     * @param arg Zbgl
     */
    public void setXliffdir(final String arg) {
        fInput.setXliffdir(arg);
        fIsFieldXliffdirProcessed = true;
    }

    /**
     * Ant^XN[xliffdir]Agr[g̃Qb^[\bhB
     *
     * ڔԍ: 3<br>
     * XLIFFt@Ci[Ă͐惋[gEtH_w肵܂BXLIFFt@C Bundle-SymbolicName fBNgɊi[邱ƂOƂ܂B<br>
     * K{Agr[głBApache Ant^XNŕKlw肳܂B<br>
     *
     * @return ̃tB[h̒l
     */
    public String getXliffdir() {
        return fInput.getXliffdir();
    }

    /**
     * Ant^XN[tmpdir]Agr[g̃Zb^[\bhB
     *
     * ڔԍ: 4<br>
     * e|fBNgw肵܂Bw̏ꍇɂ̓Jgtmpp܂B<br>
     *
     * @param arg Zbgl
     */
    public void setTmpdir(final String arg) {
        fInput.setTmpdir(arg);
        fIsFieldTmpdirProcessed = true;
    }

    /**
     * Ant^XN[tmpdir]Agr[g̃Qb^[\bhB
     *
     * ڔԍ: 4<br>
     * e|fBNgw肵܂Bw̏ꍇɂ̓Jgtmpp܂B<br>
     * ftHgl[tmp]ݒ肳Ă܂BApache Ant^XNŃAgr[g̎w肪ꍇɂ́AftHglݒ肳܂B<br>
     *
     * @return ̃tB[h̒l
     */
    public String getTmpdir() {
        return fInput.getTmpdir();
    }

    /**
     * Ant^XÑCBApache Ant ̃\bhĂяo܂B
     *
     * @throws BuildException ^XNƂĂ̗OꍇB
     */
    public final void execute() throws BuildException {
        System.out.println("BlancoNLpackGeneratorConvertXliff2PropertiesTask begin.");

        // ڔԍ[1]AAgr[g[sourcedir]͕K{͂łB̓`FbNs܂B
        if (fIsFieldSourcedirProcessed == false) {
            throw new BuildException("K{Agr[g[sourcedir]ݒ肳Ă܂B𒆒f܂B");
        }
        // ڔԍ[2]AAgr[g[targetdir]͕K{͂łB̓`FbNs܂B
        if (fIsFieldTargetdirProcessed == false) {
            throw new BuildException("K{Agr[g[targetdir]ݒ肳Ă܂B𒆒f܂B");
        }
        // ڔԍ[3]AAgr[g[xliffdir]͕K{͂łB̓`FbNs܂B
        if (fIsFieldXliffdirProcessed == false) {
            throw new BuildException("K{Agr[g[xliffdir]ݒ肳Ă܂B𒆒f܂B");
        }

        if (getVerbose()) {
            System.out.println("- verbose:[true]");
            System.out.println("- sourcedir:[" + getSourcedir() + "]");
            System.out.println("- targetdir:[" + getTargetdir() + "]");
            System.out.println("- xliffdir:[" + getXliffdir() + "]");
            System.out.println("- tmpdir:[" + getTmpdir() + "]");
        }

        try {
            // ۂAnt^XN̎又s܂B
            // ̉ӏŃRpCG[ꍇABlancoNLpackGeneratorConvertXliff2PropertiesProcessC^tF[X blanco.nlpack.generator.taskpbP[W BlancoNLpackGeneratorConvertXliff2PropertiesProcessImplNX쐬邱Ƃɂłꍇ܂B
            final BlancoNLpackGeneratorConvertXliff2PropertiesProcess proc = new BlancoNLpackGeneratorConvertXliff2PropertiesProcessImpl();
            if (proc.execute(fInput) != BlancoNLpackGeneratorConvertXliff2PropertiesBatchProcess.END_SUCCESS) {
                throw new BuildException("^XNُ͈I܂B");
            }
        } catch (IllegalArgumentException e) {
            if (getVerbose()) {
                e.printStackTrace();
            }
            throw new BuildException(e.getMessage());
        } catch (Exception e) {
            e.printStackTrace();
            throw new BuildException("^XNɗO܂B𒆒f܂B" + e.toString());
        } catch (Error e) {
            e.printStackTrace();
            throw new BuildException("^XNɃG[܂B𒆒f܂B" + e.toString());
        }
    }
}

==> blancoNLpackGenerator-0.1.20-src.zip: src/blanco/nlpack/generator/task/BlancoNLpackGeneratorConvertXliff2PropertiesTask.java <==
/*
 * ̃\[XR[h blanco FrameworkɂĎĂ܂B
 * Apache Ant^XN [BlancoNLpackGeneratorConvertXliff2Properties]̃NX
 */
package blanco.nlpack.generator.task;

import org.apache.tools.ant.BuildException;
import org.apache.tools.ant.Task;

import blanco.nlpack.generator.task.valueobject.BlancoNLpackGeneratorConvertXliff2PropertiesProcessInput;

/**
 * Apache Ant^XN [BlancoNLpackGeneratorConvertXliff2Properties]̃NXB
 *
 * [XLIFFΉc[] JavaAvP[V(EclipsevOC)  XLIFFt@C(*.xlf) 猾pbN쐬܂B<br>
 * ̃NXł́AApache Ant^XNňʓIɕKvȃ`FbNȂǂ̃R[fBO肵܂B
 * ۂ̏ pbP[W[blanco.nlpack.generator.task]BlancoNLpackGeneratorConvertXliff2PropertiesBatchProcessNX쐬ċLqĂB<br>
 * <br>
 * Ant^XNւ̑gݍݗ<br>
 * <pre>
 * &lt;taskdef name=&quot;blanconlpackgeneratorconvertxliff2properties&quot; classname=&quot;blanco.nlpack.generator.task.BlancoNLpackGeneratorConvertXliff2PropertiesTask">
 *     &lt;classpath&gt;
 *         &lt;fileset dir=&quot;lib&quot; includes=&quot;*.jar&quot; /&gt;
 *         &lt;fileset dir=&quot;lib.ant&quot; includes=&quot;*.jar&quot; /&gt;
 *     &lt;/classpath&gt;
 * &lt;/taskdef&gt;
 * </pre>
 */
public class BlancoNLpackGeneratorConvertXliff2PropertiesTask extends Task {
    /**
     * [XLIFFΉc[] JavaAvP[V(EclipsevOC)  XLIFFt@C(*.xlf) 猾pbN쐬܂B
     */
    protected BlancoNLpackGeneratorConvertXliff2PropertiesProcessInput fInput = new BlancoNLpackGeneratorConvertXliff2PropertiesProcessInput();

    /**
     * tB[h [sourcedir] ɒlZbgꂽǂB
     */
    protected boolean fIsFieldSourcedirProcessed = false;

    /**
     * tB[h [targetdir] ɒlZbgꂽǂB
     */
    protected boolean fIsFieldTargetdirProcessed = false;

    /**
     * tB[h [xliffdir] ɒlZbgꂽǂB
     */
    protected boolean fIsFieldXliffdirProcessed = false;

    /**
     * tB[h [tmpdir] ɒlZbgꂽǂB
     */
    protected boolean fIsFieldTmpdirProcessed = false;

    /**
     * verbose[hœ삳邩ǂB
     *
     * @param arg verbose[hœ삳邩ǂB
     */
    public void setVerbose(final boolean arg) {
        fInput.setVerbose(arg);
    }

    /**
     * verbose[hœ삳邩ǂB
     *
     * @return verbose[hœ삳邩ǂB
     */
    public boolean getVerbose() {
        return fInput.getVerbose();
    }

    /**
     * Ant^XN[sourcedir]Agr[g̃Zb^[\bhB
     *
     * ڔԍ: 1<br>
     * \[XfBNgB*.jart@CWJEclipsevOCB<br>
     *
     * @param arg Zbgl
     */
    public void setSourcedir(final String arg) {
        fInput.setSourcedir(arg);
        fIsFieldSourcedirProcessed = true;
    }

    /**
     * Ant^XN[sourcedir]Agr[g̃Qb^[\bhB
     *
     * ڔԍ: 1<br>
     * \[XfBNgB*.jart@CWJEclipsevOCB<br>
     * K{Agr[głBApache Ant^XNŕKlw肳܂B<br>
     *
     * @return ̃tB[h̒l
     */
    public String getSourcedir() {
        return fInput.getSourcedir();
    }

    /**
     * Ant^XN[targetdir]Agr[g̃Zb^[\bhB
     *
     * ڔԍ: 2<br>
     * pbNi[o͐fBNgB<br>
     *
     * @param arg Zbgl
     */
    public void setTargetdir(final String arg) {
        fInput.setTargetdir(arg);
        fIsFieldTargetdirProcessed = true;
    }

    /**
     * Ant^XN[targetdir]Agr[g̃Qb^[\bhB
     *
     * ڔԍ: 2<br>
     * pbNi[o͐fBNgB<br>
     * K{Agr[głBApache Ant^XNŕKlw肳܂B<br>
     *
     * @return ̃tB[h̒l
     */
    public String getTargetdir() {
        return fInput.getTargetdir();
    }

    /**
     * Ant^XN[xliffdir]Agr[g̃Zb^[\bhB
     *
     * ڔԍ: 3<br>
     * XLIFFt@Ci[Ă͐惋[gEtH_w肵܂BXLIFFt@C Bundle-SymbolicName fBNgɊi[邱ƂOƂ܂B<br>
     *
     * @param arg Zbgl
     */
    public void setXliffdir(final String arg) {
        fInput.setXliffdir(arg);
        fIsFieldXliffdirProcessed = true;
    }

    /**
     * Ant^XN[xliffdir]Agr[g̃Qb^[\bhB
     *
     * ڔԍ: 3<br>
     * XLIFFt@Ci[Ă͐惋[gEtH_w肵܂BXLIFFt@C Bundle-SymbolicName fBNgɊi[邱ƂOƂ܂B<br>
     * K{Agr[głBApache Ant^XNŕKlw肳܂B<br>
     *
     * @return ̃tB[h̒l
     */
    public String getXliffdir() {
        return fInput.getXliffdir();
    }

    /**
     * Ant^XN[tmpdir]Agr[g̃Zb^[\bhB
     *
     * ڔԍ: 4<br>
     * e|fBNgw肵܂Bw̏ꍇɂ̓Jgtmpp܂B<br>
     *
     * @param arg Zbgl
     */
    public void setTmpdir(final String arg) {
        fInput.setTmpdir(arg);
        fIsFieldTmpdirProcessed = true;
    }

    /**
     * Ant^XN[tmpdir]Agr[g̃Qb^[\bhB
     *
     * ڔԍ: 4<br>
     * e|fBNgw肵܂Bw̏ꍇɂ̓Jgtmpp܂B<br>
     * ftHgl[tmp]ݒ肳Ă܂BApache Ant^XNŃAgr[g̎w肪ꍇɂ́AftHglݒ肳܂B<br>
     *
     * @return ̃tB[h̒l
     */
    public String getTmpdir() {
        return fInput.getTmpdir();
    }

    /**
     * Ant^XÑCBApache Ant ̃\bhĂяo܂B
     *
     * @throws BuildException ^XNƂĂ̗OꍇB
     */
    @Override
    public final void execute() throws BuildException {
        System.out.println("BlancoNLpackGeneratorConvertXliff2PropertiesTask begin.");

        // ڔԍ[1]AAgr[g[sourcedir]͕K{͂łB̓`FbNs܂B
        if (fIsFieldSourcedirProcessed == false) {
            throw new BuildException("K{Agr[g[sourcedir]ݒ肳Ă܂B𒆒f܂B");
        }
        // ڔԍ[2]AAgr[g[targetdir]͕K{͂łB̓`FbNs܂B
        if (fIsFieldTargetdirProcessed == false) {
            throw new BuildException("K{Agr[g[targetdir]ݒ肳Ă܂B𒆒f܂B");
        }
        // ڔԍ[3]AAgr[g[xliffdir]͕K{͂łB̓`FbNs܂B
        if (fIsFieldXliffdirProcessed == false) {
            throw new BuildException("K{Agr[g[xliffdir]ݒ肳Ă܂B𒆒f܂B");
        }

        if (getVerbose()) {
            System.out.println("- verbose:[true]");
            System.out.println("- sourcedir:[" + getSourcedir() + "]");
            System.out.println("- targetdir:[" + getTargetdir() + "]");
            System.out.println("- xliffdir:[" + getXliffdir() + "]");
            System.out.println("- tmpdir:[" + getTmpdir() + "]");
        }

        try {
            // ۂAnt^XN̎又s܂B
            // ̉ӏŃRpCG[ꍇABlancoNLpackGeneratorConvertXliff2PropertiesProcessC^tF[X blanco.nlpack.generator.taskpbP[W BlancoNLpackGeneratorConvertXliff2PropertiesProcessImplNX쐬邱Ƃɂłꍇ܂B
            final BlancoNLpackGeneratorConvertXliff2PropertiesProcess proc = new BlancoNLpackGeneratorConvertXliff2PropertiesProcessImpl();
            if (proc.execute(fInput) != BlancoNLpackGeneratorConvertXliff2PropertiesBatchProcess.END_SUCCESS) {
                throw new BuildException("^XNُ͈I܂B");
            }
        } catch (IllegalArgumentException e) {
            if (getVerbose()) {
                e.printStackTrace();
            }
            throw new BuildException(e.getMessage());
        } catch (Exception e) {
            e.printStackTrace();
            throw new BuildException("^XNɗO܂B𒆒f܂B" + e.toString());
        } catch (Error e) {
            e.printStackTrace();
            throw new BuildException("^XNɃG[܂B𒆒f܂B" + e.toString());
        }
    }
}
